''' Djheroku for populating Heroku environment variables to Django '''
from djheroku.conf import (sendgrid, mailgun, cloudant, memcachier, identity,
                           social, allowed_hosts, autopilot)
